# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from iblai.models.app import App
from iblai.models.platform import Platform
from typing import Optional, Set
from typing_extensions import Self

class UserApp(BaseModel):
    """
    UserApp
    """ # noqa: E501
    id: StrictInt
    app: App = Field(description="The app details")
    platform: Platform = Field(description="The platform details")
    subscription: Optional[Dict[str, Any]] = Field(description="The subscription details, would contain identifier, active, created_on, last_updated")
    provider: StrictStr
    is_admin: StrictBool
    is_active: StrictBool
    metadata: Optional[Any] = None
    onboarding_completed: Optional[StrictBool] = None
    free_trial_started: Optional[StrictBool] = None
    free_trial_expired: Optional[StrictBool] = None
    has_active_subscription: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["id", "app", "platform", "subscription", "provider", "is_admin", "is_active", "metadata", "onboarding_completed", "free_trial_started", "free_trial_expired", "has_active_subscription"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserApp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "platform",
            "subscription",
            "is_admin",
            "is_active",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of app
        if self.app:
            _dict['app'] = self.app.to_dict()
        # override the default output from pydantic by calling `to_dict()` of platform
        if self.platform:
            _dict['platform'] = self.platform.to_dict()
        # set to None if subscription (nullable) is None
        # and model_fields_set contains the field
        if self.subscription is None and "subscription" in self.model_fields_set:
            _dict['subscription'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserApp from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "app": App.from_dict(obj["app"]) if obj.get("app") is not None else None,
            "platform": Platform.from_dict(obj["platform"]) if obj.get("platform") is not None else None,
            "subscription": obj.get("subscription"),
            "provider": obj.get("provider"),
            "is_admin": obj.get("is_admin"),
            "is_active": obj.get("is_active"),
            "metadata": obj.get("metadata"),
            "onboarding_completed": obj.get("onboarding_completed"),
            "free_trial_started": obj.get("free_trial_started"),
            "free_trial_expired": obj.get("free_trial_expired"),
            "has_active_subscription": obj.get("has_active_subscription")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr
from typing import List, Optional
from iblai.models.desired_skill import DesiredSkill
from iblai.models.patched_skill_threshold import PatchedSkillThreshold
from iblai.models.points_percentile import PointsPercentile
from iblai.models.reported_skill import ReportedSkill
from iblai.models.skill_detail import SkillDetail
from iblai.models.skill_info import SkillInfo
from iblai.models.skill_threshold import SkillThreshold
from iblai.models.user_skill import UserSkill
from iblai.models.user_skill_points_percentile import UserSkillPointsPercentile

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class SkillsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def skills_orgs_skills_list(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_list

        List all available skills on the platform.  This endpoint returns information about all skills that can be acquired on the platform.  Path Parameters:     org (str): The platform/organization identifier  Returns:     A list of all skills with basic information about each skill.  Access Control:     - Platform admins can access this information     - All authenticated users can access this information

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_list_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SkillInfo]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_list_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_percentile_list(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_percentile_list

        Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_percentile_list_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PointsPercentile]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_percentile_list_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/percentile/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_percentile_retrieve(
        self,
        org: StrictStr,
        skill_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_percentile_retrieve

        Retrieve percentile distribution for a specific skill.  This endpoint returns the percentile distribution of points earned by users for a specific skill.  Path Parameters:     skill_id (int): The ID of the skill to retrieve percentile information for     org (str, optional): The platform/organization identifier to filter results  Returns:     A list of percentile breakpoints for the specified skill.  Error Responses:     404 Not Found: If the specified skill doesn't exist  Access Control:     - Platform admins can access this information     - All authenticated users can access this information

        :param org: (required)
        :type org: str
        :param skill_id: (required)
        :type skill_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_percentile_retrieve_serialize(
            org=org,
            skill_id=skill_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PointsPercentile",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_percentile_retrieve_serialize(
        self,
        org,
        skill_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if skill_id is not None:
            _path_params['skill_id'] = skill_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/{skill_id}/percentile/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_retrieve(
        self,
        org: StrictStr,
        skill_name: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_retrieve

        Retrieve detailed information about a specific skill.  This endpoint returns comprehensive information about a specific skill, including its description, categories, and related courses.  Path Parameters:     org (str): The platform/organization identifier     skill_name (str): The name of the skill to retrieve details for  Returns:     Detailed information about the specified skill.  Error Responses:     404 Not Found: If the specified skill doesn't exist  Access Control:     - Platform admins can access this information     - All authenticated users can access this information

        :param org: (required)
        :type org: str
        :param skill_name: (required)
        :type skill_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_retrieve_serialize(
            org=org,
            skill_name=skill_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SkillDetail",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_retrieve_serialize(
        self,
        org,
        skill_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if skill_name is not None:
            _path_params['skill_name'] = skill_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/{skill_name}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_thresholds_create(
        self,
        org: StrictStr,
        skill_threshold: SkillThreshold,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_thresholds_create

        Manage skill thresholds for a platform.  This endpoint allows platform administrators to view, create, update, and delete skill thresholds. Skill thresholds define the minimum points required to consider a skill as acquired or mastered.  Path Parameters:     org (str): The platform/organization identifier  Methods:     GET: Retrieve all skill thresholds for the platform     POST: Create a new skill threshold     PATCH: Update an existing skill threshold     DELETE: Delete all skill thresholds for the platform  Request Body (POST):     name (str, required): The name of the threshold level (e.g., \"Beginner\", \"Intermediate\")     threshold (int, required): The minimum points required to reach this threshold  Request Body (PATCH):     name (str, required): The name of the existing threshold to update     threshold (int, required): The new minimum points value for this threshold  Returns:     GET: A list of all skill thresholds for the platform     POST/PATCH: The created or updated skill threshold with format:         {             \"name\": \"threshold_name\",             \"threshold\": threshold_value         }     DELETE: No content (204)  Error Responses:     400 Bad Request: If the request data is invalid or missing required fields     404 Not Found: If the specified platform doesn't exist or the threshold                   to update cannot be found  Access Control:     - Only platform administrators can access this endpoint

        :param org: (required)
        :type org: str
        :param skill_threshold: (required)
        :type skill_threshold: SkillThreshold
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_thresholds_create_serialize(
            org=org,
            skill_threshold=skill_threshold,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SkillThreshold",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_thresholds_create_serialize(
        self,
        org,
        skill_threshold,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if skill_threshold is not None:
            _body_params = skill_threshold


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/skills/orgs/{org}/skills/thresholds/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_thresholds_destroy(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_thresholds_destroy

        Manage skill thresholds for a platform.  This endpoint allows platform administrators to view, create, update, and delete skill thresholds. Skill thresholds define the minimum points required to consider a skill as acquired or mastered.  Path Parameters:     org (str): The platform/organization identifier  Methods:     GET: Retrieve all skill thresholds for the platform     POST: Create a new skill threshold     PATCH: Update an existing skill threshold     DELETE: Delete all skill thresholds for the platform  Request Body (POST):     name (str, required): The name of the threshold level (e.g., \"Beginner\", \"Intermediate\")     threshold (int, required): The minimum points required to reach this threshold  Request Body (PATCH):     name (str, required): The name of the existing threshold to update     threshold (int, required): The new minimum points value for this threshold  Returns:     GET: A list of all skill thresholds for the platform     POST/PATCH: The created or updated skill threshold with format:         {             \"name\": \"threshold_name\",             \"threshold\": threshold_value         }     DELETE: No content (204)  Error Responses:     400 Bad Request: If the request data is invalid or missing required fields     404 Not Found: If the specified platform doesn't exist or the threshold                   to update cannot be found  Access Control:     - Only platform administrators can access this endpoint

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_thresholds_destroy_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_thresholds_destroy_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/skills/orgs/{org}/skills/thresholds/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_thresholds_partial_update(
        self,
        org: StrictStr,
        patched_skill_threshold: Optional[PatchedSkillThreshold] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_thresholds_partial_update

        Manage skill thresholds for a platform.  This endpoint allows platform administrators to view, create, update, and delete skill thresholds. Skill thresholds define the minimum points required to consider a skill as acquired or mastered.  Path Parameters:     org (str): The platform/organization identifier  Methods:     GET: Retrieve all skill thresholds for the platform     POST: Create a new skill threshold     PATCH: Update an existing skill threshold     DELETE: Delete all skill thresholds for the platform  Request Body (POST):     name (str, required): The name of the threshold level (e.g., \"Beginner\", \"Intermediate\")     threshold (int, required): The minimum points required to reach this threshold  Request Body (PATCH):     name (str, required): The name of the existing threshold to update     threshold (int, required): The new minimum points value for this threshold  Returns:     GET: A list of all skill thresholds for the platform     POST/PATCH: The created or updated skill threshold with format:         {             \"name\": \"threshold_name\",             \"threshold\": threshold_value         }     DELETE: No content (204)  Error Responses:     400 Bad Request: If the request data is invalid or missing required fields     404 Not Found: If the specified platform doesn't exist or the threshold                   to update cannot be found  Access Control:     - Only platform administrators can access this endpoint

        :param org: (required)
        :type org: str
        :param patched_skill_threshold:
        :type patched_skill_threshold: PatchedSkillThreshold
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_thresholds_partial_update_serialize(
            org=org,
            patched_skill_threshold=patched_skill_threshold,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SkillThreshold",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_thresholds_partial_update_serialize(
        self,
        org,
        patched_skill_threshold,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_skill_threshold is not None:
            _body_params = patched_skill_threshold


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/skills/orgs/{org}/skills/thresholds/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_thresholds_retrieve(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_thresholds_retrieve

        Manage skill thresholds for a platform.  This endpoint allows platform administrators to view, create, update, and delete skill thresholds. Skill thresholds define the minimum points required to consider a skill as acquired or mastered.  Path Parameters:     org (str): The platform/organization identifier  Methods:     GET: Retrieve all skill thresholds for the platform     POST: Create a new skill threshold     PATCH: Update an existing skill threshold     DELETE: Delete all skill thresholds for the platform  Request Body (POST):     name (str, required): The name of the threshold level (e.g., \"Beginner\", \"Intermediate\")     threshold (int, required): The minimum points required to reach this threshold  Request Body (PATCH):     name (str, required): The name of the existing threshold to update     threshold (int, required): The new minimum points value for this threshold  Returns:     GET: A list of all skill thresholds for the platform     POST/PATCH: The created or updated skill threshold with format:         {             \"name\": \"threshold_name\",             \"threshold\": threshold_value         }     DELETE: No content (204)  Error Responses:     400 Bad Request: If the request data is invalid or missing required fields     404 Not Found: If the specified platform doesn't exist or the threshold                   to update cannot be found  Access Control:     - Only platform administrators can access this endpoint

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_thresholds_retrieve_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SkillThreshold",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_thresholds_retrieve_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/thresholds/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_users_desired_skills_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_users_desired_skills_retrieve

        Retrieve a user's desired skills.  This endpoint returns the skills that a user has indicated they want to develop or acquire through the platform.  Path Parameters:     org (str): The platform/organization identifier     user_id (str): The username of the user to retrieve skill information for  Returns:     The user's desired skills information.  Error Responses:     400 Bad Request: If the user doesn't exist in the platform or has no desired skills     404 Not Found: If the specified platform doesn't exist  Access Control:     - Platform admins can access any user's information     - Users can access their own information

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_users_desired_skills_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesiredSkill",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_users_desired_skills_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/users/{user_id}/desired-skills/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_users_point_percentile_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_users_point_percentile_retrieve

        Retrieve a user's total skill points and percentile ranking.  This endpoint returns the total skill points a user has earned across all skills and their percentile ranking compared to other users on the platform.  Path Parameters:     org (str): The platform/organization identifier     user_id (str): The username of the user to retrieve information for  Returns:     The user's total skill points and percentile ranking information:     - Username     - Total points earned across all skills     - Percentile ranking compared to other users  Access Control:     - Platform admins can access any user's information     - Users can access their own information

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_users_point_percentile_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserSkillPointsPercentile",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_users_point_percentile_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/users/{user_id}/point-percentile/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_users_reported_skills_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_users_reported_skills_retrieve

        Retrieve a user's self-reported skills.  This endpoint returns the skills that a user has reported having prior to or outside of the platform learning experience.  Path Parameters:     org (str): The platform/organization identifier     user_id (str): The username of the user to retrieve skill information for  Returns:     The user's self-reported skills information.  Error Responses:     400 Bad Request: If the user doesn't exist in the platform or has no reported skills     404 Not Found: If the specified platform doesn't exist  Access Control:     - Platform admins can access any user's information     - Users can access their own information

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_users_reported_skills_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportedSkill",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_users_reported_skills_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/users/{user_id}/reported-skills/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def skills_orgs_skills_users_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """skills_orgs_skills_users_retrieve

        Retrieve a user's skill information.  This endpoint returns information about skills that a user has acquired through the platform. It can return all skills or filter by a specific skill.  Path Parameters:     org (str): The platform/organization identifier     user_id (str): The username of the user to retrieve skill information for  Query Parameters:     skill_name (str, optional): Filter results to a specific skill  Returns:     When skill_name is provided:         Details about the specific skill including points earned and percentile ranking      When skill_name is not provided:         A list of all skills the user has acquired with their points  Access Control:     - Platform admins can access any user's skill information     - Users can access their own skill information

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._skills_orgs_skills_users_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserSkill",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _skills_orgs_skills_users_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/skills/orgs/{org}/skills/users/{user_id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.user_app import UserApp

class TestUserApp(unittest.TestCase):
    """UserApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserApp:
        """Test UserApp
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserApp`
        """
        model = UserApp()
        if include_optional:
            return UserApp(
                id = 56,
                app = iblai.models.app.App(
                    name = '', 
                    url = '', 
                    type = '', 
                    metadata = null, 
                    onboarding_required = True, ),
                platform = iblai.models.platform.Platform(
                    key = '', 
                    name = '', 
                    org = '', 
                    lms_url = '', 
                    cms_url = '', 
                    portal_url = '', ),
                subscription = {
                    'key' : null
                    },
                provider = '',
                is_admin = True,
                is_active = True,
                metadata = None,
                onboarding_completed = True,
                free_trial_started = True,
                free_trial_expired = True,
                has_active_subscription = True
            )
        else:
            return UserApp(
                id = 56,
                app = iblai.models.app.App(
                    name = '', 
                    url = '', 
                    type = '', 
                    metadata = null, 
                    onboarding_required = True, ),
                platform = iblai.models.platform.Platform(
                    key = '', 
                    name = '', 
                    org = '', 
                    lms_url = '', 
                    cms_url = '', 
                    portal_url = '', ),
                subscription = {
                    'key' : null
                    },
                provider = '',
                is_admin = True,
                is_active = True,
        )
        """

    def testUserApp(self):
        """Test UserApp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.career_api import CareerApi


class TestCareerApi(unittest.TestCase):
    """CareerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CareerApi()

    def tearDown(self) -> None:
        pass

    def test_career_orgs_companies_users_create(self) -> None:
        """Test case for career_orgs_companies_users_create

        """
        pass

    def test_career_orgs_companies_users_destroy(self) -> None:
        """Test case for career_orgs_companies_users_destroy

        """
        pass

    def test_career_orgs_companies_users_retrieve(self) -> None:
        """Test case for career_orgs_companies_users_retrieve

        """
        pass

    def test_career_orgs_companies_users_update(self) -> None:
        """Test case for career_orgs_companies_users_update

        """
        pass

    def test_career_orgs_education_users_create(self) -> None:
        """Test case for career_orgs_education_users_create

        """
        pass

    def test_career_orgs_education_users_destroy(self) -> None:
        """Test case for career_orgs_education_users_destroy

        """
        pass

    def test_career_orgs_education_users_retrieve(self) -> None:
        """Test case for career_orgs_education_users_retrieve

        """
        pass

    def test_career_orgs_education_users_update(self) -> None:
        """Test case for career_orgs_education_users_update

        """
        pass

    def test_career_orgs_experience_users_create(self) -> None:
        """Test case for career_orgs_experience_users_create

        """
        pass

    def test_career_orgs_experience_users_destroy(self) -> None:
        """Test case for career_orgs_experience_users_destroy

        """
        pass

    def test_career_orgs_experience_users_retrieve(self) -> None:
        """Test case for career_orgs_experience_users_retrieve

        """
        pass

    def test_career_orgs_experience_users_update(self) -> None:
        """Test case for career_orgs_experience_users_update

        """
        pass

    def test_career_orgs_institutions_users_create(self) -> None:
        """Test case for career_orgs_institutions_users_create

        """
        pass

    def test_career_orgs_institutions_users_destroy(self) -> None:
        """Test case for career_orgs_institutions_users_destroy

        """
        pass

    def test_career_orgs_institutions_users_retrieve(self) -> None:
        """Test case for career_orgs_institutions_users_retrieve

        """
        pass

    def test_career_orgs_institutions_users_update(self) -> None:
        """Test case for career_orgs_institutions_users_update

        """
        pass

    def test_career_orgs_programs_users_create(self) -> None:
        """Test case for career_orgs_programs_users_create

        """
        pass

    def test_career_orgs_programs_users_destroy(self) -> None:
        """Test case for career_orgs_programs_users_destroy

        """
        pass

    def test_career_orgs_programs_users_retrieve(self) -> None:
        """Test case for career_orgs_programs_users_retrieve

        """
        pass

    def test_career_orgs_programs_users_update(self) -> None:
        """Test case for career_orgs_programs_users_update

        """
        pass

    def test_career_resume_orgs_users_create(self) -> None:
        """Test case for career_resume_orgs_users_create

        """
        pass

    def test_career_resume_orgs_users_retrieve(self) -> None:
        """Test case for career_resume_orgs_users_retrieve

        """
        pass

    def test_career_resume_orgs_users_update(self) -> None:
        """Test case for career_resume_orgs_users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.bulk_program_invitation_create import BulkProgramInvitationCreate

class TestBulkProgramInvitationCreate(unittest.TestCase):
    """BulkProgramInvitationCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkProgramInvitationCreate:
        """Test BulkProgramInvitationCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkProgramInvitationCreate`
        """
        model = BulkProgramInvitationCreate()
        if include_optional:
            return BulkProgramInvitationCreate(
                invitation_data = [
                    iblai.models.program_invitation_create.ProgramInvitationCreate(
                        program_key = '', 
                        email = '', 
                        username = '', 
                        active = True, 
                        source = '', 
                        redirect_to = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, )
                    ],
                platform_key = ''
            )
        else:
            return BulkProgramInvitationCreate(
                invitation_data = [
                    iblai.models.program_invitation_create.ProgramInvitationCreate(
                        program_key = '', 
                        email = '', 
                        username = '', 
                        active = True, 
                        source = '', 
                        redirect_to = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, )
                    ],
        )
        """

    def testBulkProgramInvitationCreate(self):
        """Test BulkProgramInvitationCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.education import Education

class TestEducation(unittest.TestCase):
    """Education unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Education:
        """Test Education
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Education`
        """
        model = Education()
        if include_optional:
            return Education(
                id = 56,
                user = 56,
                user_info = iblai.models.user_info.UserInfo(
                    id = 56, 
                    username = '', 
                    name = '', 
                    email = '', 
                    active = True, 
                    edx_data = null, ),
                institution = iblai.models.institution.Institution(
                    id = 56, 
                    name = '', 
                    institution_type = 'university', 
                    location = '', 
                    website = '', 
                    accreditation = '', 
                    established_year = 56, 
                    data = null, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                institution_id = 56,
                degree = '',
                field_of_study = '',
                start_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                end_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                grade = '-8',
                activities = '',
                description = '',
                data = None,
                metadata = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_current = True
            )
        else:
            return Education(
                id = 56,
                user = 56,
                user_info = iblai.models.user_info.UserInfo(
                    id = 56, 
                    username = '', 
                    name = '', 
                    email = '', 
                    active = True, 
                    edx_data = null, ),
                institution = iblai.models.institution.Institution(
                    id = 56, 
                    name = '', 
                    institution_type = 'university', 
                    location = '', 
                    website = '', 
                    accreditation = '', 
                    established_year = 56, 
                    data = null, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                institution_id = 56,
                start_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testEducation(self):
        """Test Education"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.user_chat_feedback import UserChatFeedback

class TestUserChatFeedback(unittest.TestCase):
    """UserChatFeedback unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserChatFeedback:
        """Test UserChatFeedback
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserChatFeedback`
        """
        model = UserChatFeedback()
        if include_optional:
            return UserChatFeedback(
                id = 56,
                username = '',
                session = '',
                user_text = '',
                ai_response = '',
                reason = '',
                additional_feedback = '',
                rating = 1,
                inserted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                mentor = 56
            )
        else:
            return UserChatFeedback(
                id = 56,
                username = '',
                session = '',
                user_text = '',
                ai_response = '',
                reason = '',
                additional_feedback = '',
                mentor = 56,
        )
        """

    def testUserChatFeedback(self):
        """Test UserChatFeedback"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_data_set_list import PaginatedDataSetList

class TestPaginatedDataSetList(unittest.TestCase):
    """PaginatedDataSetList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedDataSetList:
        """Test PaginatedDataSetList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedDataSetList`
        """
        model = PaginatedDataSetList()
        if include_optional:
            return PaginatedDataSetList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.data_set.DataSet(
                        id = '', 
                        platform = {
                            'key' : null
                            }, 
                        name = '', 
                        prompt = '', 
                        source_url = '', 
                        source_file = '', 
                        status = 'pending', 
                        num_data_points = 56, 
                        train_split = 0, 
                        train_file = '', 
                        test_file = '', 
                        retry_attempts = 56, 
                        error_log = '', 
                        date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedDataSetList(
        )
        """

    def testPaginatedDataSetList(self):
        """Test PaginatedDataSetList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_mentor_list import PaginatedMentorList

class TestPaginatedMentorList(unittest.TestCase):
    """PaginatedMentorList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedMentorList:
        """Test PaginatedMentorList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedMentorList`
        """
        model = PaginatedMentorList()
        if include_optional:
            return PaginatedMentorList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.mentor.Mentor(
                        name = '', 
                        unique_id = '', 
                        flow = null, 
                        slug = 'z', 
                        platform = '', 
                        allow_anonymous = True, 
                        metadata = null, 
                        enable_moderation = True, 
                        is_proactive = True, 
                        proactive_prompt = '', 
                        moderation_system_prompt = '', 
                        moderation_response = '', 
                        safety_system_prompt = '', 
                        safety_response = '', 
                        enable_safety_system = True, 
                        proactive_message = '', 
                        created_by = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedMentorList(
        )
        """

    def testPaginatedMentorList(self):
        """Test PaginatedMentorList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.value import Value

class TestValue(unittest.TestCase):
    """Value unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Value:
        """Test Value
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Value`
        """
        model = Value()
        if include_optional:
            return Value(
                data = iblai.models.value_data.ValueData(
                    value = 1.337, )
            )
        else:
            return Value(
                data = iblai.models.value_data.ValueData(
                    value = 1.337, ),
        )
        """

    def testValue(self):
        """Test Value"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.patched_prompt_prompt_visibility import PatchedPromptPromptVisibility
from typing import Optional, Set
from typing_extensions import Self

class Prompt(BaseModel):
    """
    Prompt
    """ # noqa: E501
    id: StrictInt
    mentor: Optional[StrictStr] = None
    tone: Optional[StrictStr] = None
    style: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    tags: Optional[List[StrictInt]] = None
    is_system: Optional[StrictBool] = True
    metadata: Optional[Any] = None
    category: Optional[StrictStr] = None
    prompt: StrictStr
    title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    description: Optional[StrictStr] = None
    prompt_visibility: Optional[PatchedPromptPromptVisibility] = None
    created_at: datetime
    updated_at: datetime
    created_by: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    platform: StrictInt
    __properties: ClassVar[List[str]] = ["id", "mentor", "tone", "style", "language", "tags", "is_system", "metadata", "category", "prompt", "title", "description", "prompt_visibility", "created_at", "updated_at", "created_by", "platform"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Prompt from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "created_at",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of prompt_visibility
        if self.prompt_visibility:
            _dict['prompt_visibility'] = self.prompt_visibility.to_dict()
        # set to None if tone (nullable) is None
        # and model_fields_set contains the field
        if self.tone is None and "tone" in self.model_fields_set:
            _dict['tone'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if prompt_visibility (nullable) is None
        # and model_fields_set contains the field
        if self.prompt_visibility is None and "prompt_visibility" in self.model_fields_set:
            _dict['prompt_visibility'] = None

        # set to None if created_by (nullable) is None
        # and model_fields_set contains the field
        if self.created_by is None and "created_by" in self.model_fields_set:
            _dict['created_by'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Prompt from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "mentor": obj.get("mentor"),
            "tone": obj.get("tone"),
            "style": obj.get("style"),
            "language": obj.get("language"),
            "tags": obj.get("tags"),
            "is_system": obj.get("is_system") if obj.get("is_system") is not None else True,
            "metadata": obj.get("metadata"),
            "category": obj.get("category"),
            "prompt": obj.get("prompt"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "prompt_visibility": PatchedPromptPromptVisibility.from_dict(obj["prompt_visibility"]) if obj.get("prompt_visibility") is not None else None,
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "created_by": obj.get("created_by"),
            "platform": obj.get("platform")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.core_api import CoreApi


class TestCoreApi(unittest.TestCase):
    """CoreApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CoreApi()

    def tearDown(self) -> None:
        pass

    def test_core_lti1p3_provider_lti_keys_create(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_create

        """
        pass

    def test_core_lti1p3_provider_lti_keys_destroy(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_destroy

        """
        pass

    def test_core_lti1p3_provider_lti_keys_list(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_list

        """
        pass

    def test_core_lti1p3_provider_lti_keys_retrieve(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_retrieve

        """
        pass

    def test_core_lti1p3_provider_lti_keys_update(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_update

        """
        pass

    def test_core_lti1p3_provider_lti_tools_create(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_create

        """
        pass

    def test_core_lti1p3_provider_lti_tools_destroy(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_destroy

        """
        pass

    def test_core_lti1p3_provider_lti_tools_list(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_list

        """
        pass

    def test_core_lti1p3_provider_lti_tools_retrieve(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_retrieve

        """
        pass

    def test_core_lti1p3_provider_lti_tools_update(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_update

        """
        pass

    def test_core_orgs_dark_mode_logo_create_create(self) -> None:
        """Test case for core_orgs_dark_mode_logo_create_create

        """
        pass

    def test_core_orgs_dark_mode_logo_retrieve(self) -> None:
        """Test case for core_orgs_dark_mode_logo_retrieve

        """
        pass

    def test_core_orgs_favicon_create_create(self) -> None:
        """Test case for core_orgs_favicon_create_create

        """
        pass

    def test_core_orgs_favicon_retrieve(self) -> None:
        """Test case for core_orgs_favicon_retrieve

        """
        pass

    def test_core_orgs_logo_create_create(self) -> None:
        """Test case for core_orgs_logo_create_create

        """
        pass

    def test_core_orgs_logo_retrieve(self) -> None:
        """Test case for core_orgs_logo_retrieve

        """
        pass

    def test_core_orgs_metadata_partial_update(self) -> None:
        """Test case for core_orgs_metadata_partial_update

        """
        pass

    def test_core_orgs_metadata_retrieve(self) -> None:
        """Test case for core_orgs_metadata_retrieve

        """
        pass

    def test_core_orgs_metadata_update(self) -> None:
        """Test case for core_orgs_metadata_update

        """
        pass

    def test_core_orgs_redirect_tokens_create(self) -> None:
        """Test case for core_orgs_redirect_tokens_create

        """
        pass

    def test_core_orgs_redirect_tokens_delete_destroy(self) -> None:
        """Test case for core_orgs_redirect_tokens_delete_destroy

        """
        pass

    def test_core_orgs_redirect_tokens_retrieve(self) -> None:
        """Test case for core_orgs_redirect_tokens_retrieve

        """
        pass

    def test_core_orgs_thumbnail_create_create(self) -> None:
        """Test case for core_orgs_thumbnail_create_create

        """
        pass

    def test_core_orgs_thumbnail_retrieve(self) -> None:
        """Test case for core_orgs_thumbnail_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_settings_public import MentorSettingsPublic

class TestMentorSettingsPublic(unittest.TestCase):
    """MentorSettingsPublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorSettingsPublic:
        """Test MentorSettingsPublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorSettingsPublic`
        """
        model = MentorSettingsPublic()
        if include_optional:
            return MentorSettingsPublic(
                id = 56,
                display_name = '',
                profile_image = '',
                initial_message = '',
                suggested_message = '',
                theme = 'dark',
                user_message_color = '',
                mentor_bubble_color = '',
                align_mentor_bubble = 'left',
                mentor = '',
                mentor_slug = '',
                mentor_unique_id = '',
                metadata = None,
                mentor_visibility = None,
                enable_image_generation = True,
                enable_web_browsing = True,
                enable_code_interpreter = True,
                custom_css = '',
                allow_anonymous = True,
                mentor_description = '',
                suggested_prompts = None,
                proactive_response = '',
                greeting_method = '',
                mentor_tools = None,
                can_use_tools = True,
                llm_name = '',
                proactive_prompt = '',
                enable_memory_component = True,
                enable_email_chat = True,
                enable_spaced_repetition = True,
                enable_instruction_mode = True,
                enable_socratic_mode = True,
                is_guided_mentor = True,
                enable_guided_prompts = True,
                enable_moderation = True,
                enable_post_processing_system = True,
                enable_safety_system = True,
                forkable = True,
                forkable_with_training_data = True
            )
        else:
            return MentorSettingsPublic(
                id = 56,
                mentor = '',
                mentor_slug = '',
                mentor_unique_id = '',
                metadata = None,
                allow_anonymous = True,
                mentor_description = '',
                suggested_prompts = None,
                proactive_response = '',
                greeting_method = '',
                mentor_tools = None,
                can_use_tools = True,
                llm_name = '',
                proactive_prompt = '',
                enable_memory_component = True,
                enable_email_chat = True,
                enable_spaced_repetition = True,
                enable_instruction_mode = True,
                enable_socratic_mode = True,
                is_guided_mentor = True,
                enable_guided_prompts = True,
                enable_moderation = True,
                enable_post_processing_system = True,
                enable_safety_system = True,
                forkable = True,
                forkable_with_training_data = True,
        )
        """

    def testMentorSettingsPublic(self):
        """Test MentorSettingsPublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.program_search import ProgramSearch

class TestProgramSearch(unittest.TestCase):
    """ProgramSearch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProgramSearch:
        """Test ProgramSearch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProgramSearch`
        """
        model = ProgramSearch()
        if include_optional:
            return ProgramSearch(
                course_list = [
                    iblai.models.program_course_position.ProgramCoursePosition(
                        course_id = '', 
                        name = '', 
                        slug = '', 
                        position = 56, )
                    ],
                program_id = '',
                program_key = '',
                name = '',
                enabled = True,
                slug = 'z',
                org = '',
                platform_key = '',
                program_type = '',
                data = None
            )
        else:
            return ProgramSearch(
                course_list = [
                    iblai.models.program_course_position.ProgramCoursePosition(
                        course_id = '', 
                        name = '', 
                        slug = '', 
                        position = 56, )
                    ],
                program_id = '',
                program_key = '',
                platform_key = '',
                program_type = '',
        )
        """

    def testProgramSearch(self):
        """Test ProgramSearch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.catalog_api import CatalogApi


class TestCatalogApi(unittest.TestCase):
    """CatalogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CatalogApi()

    def tearDown(self) -> None:
        pass

    def test_catalog_access_requests_course_manage_create(self) -> None:
        """Test case for catalog_access_requests_course_manage_create

        """
        pass

    def test_catalog_access_requests_course_manage_retrieve(self) -> None:
        """Test case for catalog_access_requests_course_manage_retrieve

        """
        pass

    def test_catalog_access_requests_course_request_create(self) -> None:
        """Test case for catalog_access_requests_course_request_create

        """
        pass

    def test_catalog_access_requests_course_request_retrieve(self) -> None:
        """Test case for catalog_access_requests_course_request_retrieve

        """
        pass

    def test_catalog_conditionals_course_eligibility_retrieve(self) -> None:
        """Test case for catalog_conditionals_course_eligibility_retrieve

        """
        pass

    def test_catalog_conditionals_course_prerequisites_manage_bulk_create(self) -> None:
        """Test case for catalog_conditionals_course_prerequisites_manage_bulk_create

        """
        pass

    def test_catalog_conditionals_course_prerequisites_manage_retrieve(self) -> None:
        """Test case for catalog_conditionals_course_prerequisites_manage_retrieve

        """
        pass

    def test_catalog_courses_create(self) -> None:
        """Test case for catalog_courses_create

        """
        pass

    def test_catalog_courses_destroy(self) -> None:
        """Test case for catalog_courses_destroy

        """
        pass

    def test_catalog_courses_list(self) -> None:
        """Test case for catalog_courses_list

        """
        pass

    def test_catalog_eligibility_courses_check_retrieve(self) -> None:
        """Test case for catalog_eligibility_courses_check_retrieve

        """
        pass

    def test_catalog_eligibility_courses_list(self) -> None:
        """Test case for catalog_eligibility_courses_list

        """
        pass

    def test_catalog_enrollment_courses_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_courses_search_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_create(self) -> None:
        """Test case for catalog_enrollment_pathways_create

        """
        pass

    def test_catalog_enrollment_pathways_destroy(self) -> None:
        """Test case for catalog_enrollment_pathways_destroy

        """
        pass

    def test_catalog_enrollment_pathways_retrieve(self) -> None:
        """Test case for catalog_enrollment_pathways_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_pathways_search_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_self_create(self) -> None:
        """Test case for catalog_enrollment_pathways_self_create

        """
        pass

    def test_catalog_enrollment_pathways_self_destroy(self) -> None:
        """Test case for catalog_enrollment_pathways_self_destroy

        """
        pass

    def test_catalog_enrollment_programs_create(self) -> None:
        """Test case for catalog_enrollment_programs_create

        """
        pass

    def test_catalog_enrollment_programs_destroy(self) -> None:
        """Test case for catalog_enrollment_programs_destroy

        """
        pass

    def test_catalog_enrollment_programs_retrieve(self) -> None:
        """Test case for catalog_enrollment_programs_retrieve

        """
        pass

    def test_catalog_enrollment_programs_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_programs_search_retrieve

        """
        pass

    def test_catalog_enrollment_programs_self_create(self) -> None:
        """Test case for catalog_enrollment_programs_self_create

        """
        pass

    def test_catalog_enrollment_programs_self_destroy(self) -> None:
        """Test case for catalog_enrollment_programs_self_destroy

        """
        pass

    def test_catalog_increment_create(self) -> None:
        """Test case for catalog_increment_create

        """
        pass

    def test_catalog_increment_retrieve(self) -> None:
        """Test case for catalog_increment_retrieve

        """
        pass

    def test_catalog_invitations_course_blank_create(self) -> None:
        """Test case for catalog_invitations_course_blank_create

        """
        pass

    def test_catalog_invitations_course_bulk_create(self) -> None:
        """Test case for catalog_invitations_course_bulk_create

        """
        pass

    def test_catalog_invitations_course_create(self) -> None:
        """Test case for catalog_invitations_course_create

        """
        pass

    def test_catalog_invitations_course_destroy(self) -> None:
        """Test case for catalog_invitations_course_destroy

        """
        pass

    def test_catalog_invitations_course_redeem_create(self) -> None:
        """Test case for catalog_invitations_course_redeem_create

        """
        pass

    def test_catalog_invitations_course_retrieve(self) -> None:
        """Test case for catalog_invitations_course_retrieve

        """
        pass

    def test_catalog_invitations_platform_blank_create(self) -> None:
        """Test case for catalog_invitations_platform_blank_create

        """
        pass

    def test_catalog_invitations_platform_bulk_create(self) -> None:
        """Test case for catalog_invitations_platform_bulk_create

        """
        pass

    def test_catalog_invitations_platform_check_retrieve(self) -> None:
        """Test case for catalog_invitations_platform_check_retrieve

        """
        pass

    def test_catalog_invitations_platform_create(self) -> None:
        """Test case for catalog_invitations_platform_create

        """
        pass

    def test_catalog_invitations_platform_destroy(self) -> None:
        """Test case for catalog_invitations_platform_destroy

        """
        pass

    def test_catalog_invitations_platform_redeem_create(self) -> None:
        """Test case for catalog_invitations_platform_redeem_create

        """
        pass

    def test_catalog_invitations_platform_retrieve(self) -> None:
        """Test case for catalog_invitations_platform_retrieve

        """
        pass

    def test_catalog_invitations_program_blank_create(self) -> None:
        """Test case for catalog_invitations_program_blank_create

        """
        pass

    def test_catalog_invitations_program_bulk_create(self) -> None:
        """Test case for catalog_invitations_program_bulk_create

        """
        pass

    def test_catalog_invitations_program_create(self) -> None:
        """Test case for catalog_invitations_program_create

        """
        pass

    def test_catalog_invitations_program_destroy(self) -> None:
        """Test case for catalog_invitations_program_destroy

        """
        pass

    def test_catalog_invitations_program_redeem_create(self) -> None:
        """Test case for catalog_invitations_program_redeem_create

        """
        pass

    def test_catalog_invitations_program_retrieve(self) -> None:
        """Test case for catalog_invitations_program_retrieve

        """
        pass

    def test_catalog_licenses_course_assignment_create(self) -> None:
        """Test case for catalog_licenses_course_assignment_create

        """
        pass

    def test_catalog_licenses_course_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_course_assignment_destroy

        """
        pass

    def test_catalog_licenses_course_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_create

        """
        pass

    def test_catalog_licenses_course_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_course_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_course_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_course_assignment_retrieve

        """
        pass

    def test_catalog_licenses_course_create_create(self) -> None:
        """Test case for catalog_licenses_course_create_create

        """
        pass

    def test_catalog_licenses_course_retrieve(self) -> None:
        """Test case for catalog_licenses_course_retrieve

        """
        pass

    def test_catalog_licenses_course_update_create(self) -> None:
        """Test case for catalog_licenses_course_update_create

        """
        pass

    def test_catalog_licenses_platform_create_create(self) -> None:
        """Test case for catalog_licenses_platform_create_create

        """
        pass

    def test_catalog_licenses_platform_retrieve(self) -> None:
        """Test case for catalog_licenses_platform_retrieve

        """
        pass

    def test_catalog_licenses_platform_update_create(self) -> None:
        """Test case for catalog_licenses_platform_update_create

        """
        pass

    def test_catalog_licenses_program_assignment_create(self) -> None:
        """Test case for catalog_licenses_program_assignment_create

        """
        pass

    def test_catalog_licenses_program_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_program_assignment_destroy

        """
        pass

    def test_catalog_licenses_program_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_create

        """
        pass

    def test_catalog_licenses_program_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_program_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_program_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_program_assignment_retrieve

        """
        pass

    def test_catalog_licenses_program_create_create(self) -> None:
        """Test case for catalog_licenses_program_create_create

        """
        pass

    def test_catalog_licenses_program_retrieve(self) -> None:
        """Test case for catalog_licenses_program_retrieve

        """
        pass

    def test_catalog_licenses_program_update_create(self) -> None:
        """Test case for catalog_licenses_program_update_create

        """
        pass

    def test_catalog_licenses_user_assignment_check_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_check_retrieve

        """
        pass

    def test_catalog_licenses_user_assignment_create(self) -> None:
        """Test case for catalog_licenses_user_assignment_create

        """
        pass

    def test_catalog_licenses_user_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_user_assignment_destroy

        """
        pass

    def test_catalog_licenses_user_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_create

        """
        pass

    def test_catalog_licenses_user_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_user_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_user_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_retrieve

        """
        pass

    def test_catalog_licenses_user_create_create(self) -> None:
        """Test case for catalog_licenses_user_create_create

        """
        pass

    def test_catalog_licenses_user_retrieve(self) -> None:
        """Test case for catalog_licenses_user_retrieve

        """
        pass

    def test_catalog_licenses_user_update_create(self) -> None:
        """Test case for catalog_licenses_user_update_create

        """
        pass

    def test_catalog_metadata_choices_retrieve(self) -> None:
        """Test case for catalog_metadata_choices_retrieve

        """
        pass

    def test_catalog_metadata_course_create(self) -> None:
        """Test case for catalog_metadata_course_create

        """
        pass

    def test_catalog_metadata_course_create2(self) -> None:
        """Test case for catalog_metadata_course_create2

        """
        pass

    def test_catalog_metadata_course_public_retrieve(self) -> None:
        """Test case for catalog_metadata_course_public_retrieve

        """
        pass

    def test_catalog_metadata_course_public_retrieve2(self) -> None:
        """Test case for catalog_metadata_course_public_retrieve2

        """
        pass

    def test_catalog_metadata_course_retrieve(self) -> None:
        """Test case for catalog_metadata_course_retrieve

        """
        pass

    def test_catalog_metadata_course_retrieve2(self) -> None:
        """Test case for catalog_metadata_course_retrieve2

        """
        pass

    def test_catalog_metadata_course_search_create(self) -> None:
        """Test case for catalog_metadata_course_search_create

        """
        pass

    def test_catalog_metadata_program_create(self) -> None:
        """Test case for catalog_metadata_program_create

        """
        pass

    def test_catalog_metadata_program_create2(self) -> None:
        """Test case for catalog_metadata_program_create2

        """
        pass

    def test_catalog_metadata_program_public_retrieve(self) -> None:
        """Test case for catalog_metadata_program_public_retrieve

        """
        pass

    def test_catalog_metadata_program_public_retrieve2(self) -> None:
        """Test case for catalog_metadata_program_public_retrieve2

        """
        pass

    def test_catalog_metadata_program_retrieve(self) -> None:
        """Test case for catalog_metadata_program_retrieve

        """
        pass

    def test_catalog_metadata_program_retrieve2(self) -> None:
        """Test case for catalog_metadata_program_retrieve2

        """
        pass

    def test_catalog_milestones_completions_course_catalog_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_course_catalog_retrieve

        """
        pass

    def test_catalog_milestones_completions_course_manage_create(self) -> None:
        """Test case for catalog_milestones_completions_course_manage_create

        """
        pass

    def test_catalog_milestones_completions_course_manage_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_course_manage_retrieve

        """
        pass

    def test_catalog_milestones_completions_pathway_query_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_pathway_query_retrieve

        """
        pass

    def test_catalog_milestones_completions_program_query_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_program_query_retrieve

        """
        pass

    def test_catalog_milestones_completions_resource_manage_create(self) -> None:
        """Test case for catalog_milestones_completions_resource_manage_create

        """
        pass

    def test_catalog_milestones_completions_resource_manage_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_resource_manage_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_block_create(self) -> None:
        """Test case for catalog_milestones_skill_points_block_create

        """
        pass

    def test_catalog_milestones_skill_points_block_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_block_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_course_create(self) -> None:
        """Test case for catalog_milestones_skill_points_course_create

        """
        pass

    def test_catalog_milestones_skill_points_course_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_course_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_platform_bulk_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_bulk_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_destroy(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_destroy

        """
        pass

    def test_catalog_milestones_skill_points_platform_group_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_group_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_user_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_user_retrieve

        """
        pass

    def test_catalog_pathways_create(self) -> None:
        """Test case for catalog_pathways_create

        """
        pass

    def test_catalog_pathways_destroy(self) -> None:
        """Test case for catalog_pathways_destroy

        """
        pass

    def test_catalog_pathways_list(self) -> None:
        """Test case for catalog_pathways_list

        """
        pass

    def test_catalog_programs_create(self) -> None:
        """Test case for catalog_programs_create

        """
        pass

    def test_catalog_programs_destroy(self) -> None:
        """Test case for catalog_programs_destroy

        """
        pass

    def test_catalog_programs_list(self) -> None:
        """Test case for catalog_programs_list

        """
        pass

    def test_catalog_recommendation_courses_retrieve(self) -> None:
        """Test case for catalog_recommendation_courses_retrieve

        """
        pass

    def test_catalog_resources_create(self) -> None:
        """Test case for catalog_resources_create

        Create or update a resource with optional image upload
        """
        pass

    def test_catalog_resources_destroy(self) -> None:
        """Test case for catalog_resources_destroy

        """
        pass

    def test_catalog_resources_list(self) -> None:
        """Test case for catalog_resources_list

        """
        pass

    def test_catalog_reviews_course_info_retrieve(self) -> None:
        """Test case for catalog_reviews_course_info_retrieve

        """
        pass

    def test_catalog_reviews_course_retrieve(self) -> None:
        """Test case for catalog_reviews_course_retrieve

        """
        pass

    def test_catalog_reviews_course_update_create(self) -> None:
        """Test case for catalog_reviews_course_update_create

        """
        pass

    def test_catalog_reviews_course_update_destroy(self) -> None:
        """Test case for catalog_reviews_course_update_destroy

        """
        pass

    def test_catalog_reviews_program_info_retrieve(self) -> None:
        """Test case for catalog_reviews_program_info_retrieve

        """
        pass

    def test_catalog_reviews_program_retrieve(self) -> None:
        """Test case for catalog_reviews_program_retrieve

        """
        pass

    def test_catalog_reviews_program_update_create(self) -> None:
        """Test case for catalog_reviews_program_update_create

        """
        pass

    def test_catalog_reviews_program_update_destroy(self) -> None:
        """Test case for catalog_reviews_program_update_destroy

        """
        pass

    def test_catalog_roles_create(self) -> None:
        """Test case for catalog_roles_create

        """
        pass

    def test_catalog_roles_desired_create(self) -> None:
        """Test case for catalog_roles_desired_create

        """
        pass

    def test_catalog_roles_desired_retrieve(self) -> None:
        """Test case for catalog_roles_desired_retrieve

        """
        pass

    def test_catalog_roles_public_create(self) -> None:
        """Test case for catalog_roles_public_create

        """
        pass

    def test_catalog_roles_reported_create(self) -> None:
        """Test case for catalog_roles_reported_create

        """
        pass

    def test_catalog_roles_reported_retrieve(self) -> None:
        """Test case for catalog_roles_reported_retrieve

        """
        pass

    def test_catalog_roles_retrieve(self) -> None:
        """Test case for catalog_roles_retrieve

        """
        pass

    def test_catalog_search_programs_create(self) -> None:
        """Test case for catalog_search_programs_create

        """
        pass

    def test_catalog_skills_create(self) -> None:
        """Test case for catalog_skills_create

        """
        pass

    def test_catalog_skills_desired_create(self) -> None:
        """Test case for catalog_skills_desired_create

        """
        pass

    def test_catalog_skills_desired_retrieve(self) -> None:
        """Test case for catalog_skills_desired_retrieve

        """
        pass

    def test_catalog_skills_public_create(self) -> None:
        """Test case for catalog_skills_public_create

        """
        pass

    def test_catalog_skills_reported_create(self) -> None:
        """Test case for catalog_skills_reported_create

        """
        pass

    def test_catalog_skills_reported_retrieve(self) -> None:
        """Test case for catalog_skills_reported_retrieve

        """
        pass

    def test_catalog_skills_retrieve(self) -> None:
        """Test case for catalog_skills_retrieve

        """
        pass

    def test_catalog_suggestions_course_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_course_manage_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_create

        """
        pass

    def test_catalog_suggestions_course_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_course_manage_destroy

        """
        pass

    def test_catalog_suggestions_course_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_create

        """
        pass

    def test_catalog_suggestions_course_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_course_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_course_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_manage_retrieve

        """
        pass

    def test_catalog_suggestions_course_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_user_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_destroy

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_user_retrieve

        """
        pass

    def test_catalog_suggestions_program_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_program_manage_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_create

        """
        pass

    def test_catalog_suggestions_program_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_program_manage_destroy

        """
        pass

    def test_catalog_suggestions_program_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_create

        """
        pass

    def test_catalog_suggestions_program_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_program_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_program_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_manage_retrieve

        """
        pass

    def test_catalog_suggestions_program_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_user_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class GCPTenantLaunchRequest(BaseModel):
    """
    GCPTenantLaunchRequest
    """ # noqa: E501
    username: StrictStr
    email: StrictStr
    firstname: Optional[StrictStr] = ''
    lastname: Optional[StrictStr] = ''
    password: Optional[StrictStr] = None
    name: StrictStr = Field(description="Organization name")
    key: StrictStr = Field(description="Unique key for the organization")
    ignore_user_exists: Optional[StrictBool] = False
    x_gcp_marketplace_token: StrictStr = Field(description="GCP Marketplace token")
    product_id: Optional[StrictStr] = Field(default='', description="GCP product to subscribe to")
    __properties: ClassVar[List[str]] = ["username", "email", "firstname", "lastname", "password", "name", "key", "ignore_user_exists", "x_gcp_marketplace_token", "product_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GCPTenantLaunchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GCPTenantLaunchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "username": obj.get("username"),
            "email": obj.get("email"),
            "firstname": obj.get("firstname") if obj.get("firstname") is not None else '',
            "lastname": obj.get("lastname") if obj.get("lastname") is not None else '',
            "password": obj.get("password"),
            "name": obj.get("name"),
            "key": obj.get("key"),
            "ignore_user_exists": obj.get("ignore_user_exists") if obj.get("ignore_user_exists") is not None else False,
            "x_gcp_marketplace_token": obj.get("x_gcp_marketplace_token"),
            "product_id": obj.get("product_id") if obj.get("product_id") is not None else ''
        })
        return _obj


